Interface: BubbleControllerDatasetOptions | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: BubbleControllerDatasetOptions

## # Hierarchy

- `ControllerDatasetOptions`

- `ScriptableAndArrayOptions`<`PointOptions`, `ScriptableContext`<`"bubble"`>>

- `ScriptableAndArrayOptions`<`PointHoverOptions`, `ScriptableContext`<`"bubble"`>>

  ↳ `BubbleControllerDatasetOptions`

## # Properties

### # backgroundColor

• backgroundColor: `ScriptableAndArray`<`Color`, `ScriptableContext`<`"bubble"`>>

#### # Inherited from

ScriptableAndArrayOptions.backgroundColor

#### # Defined in

index.esm.d.ts:1696
(opens new window)

### # borderColor

• borderColor: `ScriptableAndArray`<`Color`, `ScriptableContext`<`"bubble"`>>

#### # Inherited from

ScriptableAndArrayOptions.borderColor

#### # Defined in

index.esm.d.ts:1695
(opens new window)

### # borderWidth

• borderWidth: `ScriptableAndArray`<`number`, `ScriptableContext`<`"bubble"`>>

#### # Inherited from

ScriptableAndArrayOptions.borderWidth

#### # Defined in

index.esm.d.ts:1694
(opens new window)

### # clip

• clip: `number` | `false` | `ChartArea`

How to clip relative to chartArea. Positive value allows overflow, negative value clips that many pixels inside chartArea. 0 = clip at chartArea. Clipping can also be configured per side: clip: {left: 5, top: false, right: -2, bottom: 0}

#### # Inherited from

ControllerDatasetOptions.clip

#### # Defined in

index.esm.d.ts:70
(opens new window)

### # drawActiveElementsOnTop

• drawActiveElementsOnTop: `ScriptableAndArray`<`boolean`, `ScriptableContext`<`"bubble"`>>

Draw the active elements over the other elements of the dataset,

`default` true

#### # Inherited from

ScriptableAndArrayOptions.drawActiveElementsOnTop

#### # Defined in

index.esm.d.ts:1904
(opens new window)

### # hidden

• hidden: `boolean`

Configures the visibility state of the dataset. Set it to true, to hide the dataset from the chart.

`default` false

#### # Inherited from

ControllerDatasetOptions.hidden

#### # Defined in

index.esm.d.ts:88
(opens new window)

### # hitRadius

• hitRadius: `ScriptableAndArray`<`number`, `ScriptableContext`<`"bubble"`>>

Extra radius added to point radius for hit detection.

`default` 1

#### # Inherited from

ScriptableAndArrayOptions.hitRadius

#### # Defined in

index.esm.d.ts:1889
(opens new window)

### # hoverBackgroundColor

• hoverBackgroundColor: `ScriptableAndArray`<`Color`, `ScriptableContext`<`"bubble"`>>

#### # Inherited from

ScriptableAndArrayOptions.hoverBackgroundColor

#### # Defined in

index.esm.d.ts:1702
(opens new window)

### # hoverBorderColor

• hoverBorderColor: `ScriptableAndArray`<`Color`, `ScriptableContext`<`"bubble"`>>

#### # Inherited from

ScriptableAndArrayOptions.hoverBorderColor

#### # Defined in

index.esm.d.ts:1701
(opens new window)

### # hoverBorderWidth

• hoverBorderWidth: `ScriptableAndArray`<`number`, `ScriptableContext`<`"bubble"`>>

#### # Inherited from

ScriptableAndArrayOptions.hoverBorderWidth

#### # Defined in

index.esm.d.ts:1700
(opens new window)

### # hoverRadius

• hoverRadius: `ScriptableAndArray`<`number`, `ScriptableContext`<`"bubble"`>>

Point radius when hovered.

`default` 4

#### # Inherited from

ScriptableAndArrayOptions.hoverRadius

#### # Defined in

index.esm.d.ts:1912
(opens new window)

### # indexAxis

• indexAxis: `"x"` | `"y"`

The base axis of the chart. 'x' for vertical charts and 'y' for horizontal charts.

`default` 'x'

#### # Inherited from

ControllerDatasetOptions.indexAxis

#### # Defined in

index.esm.d.ts:66
(opens new window)

### # label

• label: `string`

The label for the dataset which appears in the legend and tooltips.

#### # Inherited from

ControllerDatasetOptions.label

#### # Defined in

index.esm.d.ts:74
(opens new window)

### # normalized

• normalized: `boolean`

Chart.js is fastest if you provide data with indices that are unique, sorted, and consistent across datasets and provide the normalized: true option to let Chart.js know that you have done so.

#### # Inherited from

ControllerDatasetOptions.normalized

#### # Defined in

index.esm.d.ts:58
(opens new window)

### # order

• order: `number`

The drawing order of dataset. Also affects order for stacking, tooltip and legend.

#### # Inherited from

ControllerDatasetOptions.order

#### # Defined in

index.esm.d.ts:78
(opens new window)

### # parsing

• parsing: `false` | { [key: string]: `string`; }

How to parse the dataset. The parsing can be disabled by specifying parsing: false at chart options or dataset. If parsing is disabled, data must be sorted and in the formats the associated chart type and scales use internally.

#### # Inherited from

ControllerDatasetOptions.parsing

#### # Defined in

index.esm.d.ts:49
(opens new window)

### # pointStyle

• pointStyle: `ScriptableAndArray`<`PointStyle`, `ScriptableContext`<`"bubble"`>>

Point style

`default` 'circle;

#### # Inherited from

ScriptableAndArrayOptions.pointStyle

#### # Defined in

index.esm.d.ts:1894
(opens new window)

### # radius

• radius: `ScriptableAndArray`<`number`, `ScriptableContext`<`"bubble"`>>

Point radius

`default` 3

#### # Inherited from

ScriptableAndArrayOptions.radius

#### # Defined in

index.esm.d.ts:1884
(opens new window)

### # rotation

• rotation: `ScriptableAndArray`<`number`, `ScriptableContext`<`"bubble"`>>

Point rotation (in degrees).

`default` 0

#### # Inherited from

ScriptableAndArrayOptions.rotation

#### # Defined in

index.esm.d.ts:1899
(opens new window)

### # stack

• stack: `string`

The ID of the group to which this dataset belongs to (when stacked, each group will be a separate stack).

#### # Inherited from

ControllerDatasetOptions.stack

#### # Defined in

index.esm.d.ts:83
(opens new window)